/* *********************************************************
               Function declarations
  ********************************************************* */

void lpc_pll_init(void);
void feed(void);

void IRQ_Routine (void)   __attribute__ ((interrupt("IRQ")));
void FIQ_Routine (void)   __attribute__ ((interrupt("FIQ")));
void SWI_Routine (void)   __attribute__ ((interrupt("SWI")));
void UNDEF_Routine (void) __attribute__ ((interrupt("UNDEF")));

/**********************************************************
                  Header files
 **********************************************************/
#include "lpc214x.h"
#include "lpc_config.h"
#include "uart.h"

#define LED (1<<21)

/**********************************************************
                  Global Variables
 **********************************************************/
int		q;				// global uninitialized variable
int		r;				// global uninitialized variable
int		s;				// global uninitialized variable

short	h = 2;			// global initialized variable
short	i = 3;			// global initialized variable
char	j = 6;			// global initialized variable




/**********************************************************
                       MAIN
**********************************************************/

int	main (void) {

	long			j;								// loop counter (stack variable)
	static int		a,b,c;							// static uninitialized variables
	static	char	d;								// static uninitialized variables
	static int		w = 1;							// static initialized variable
	static long	x = 5;								// static initialized variable
	static	char	y = 0x04;						// static initialized variable
	static int		z = 7;							// static initialized variable
	uint32_t dl, u32 = 12345678l;
	const	char	*pText = "\r\nThe Rain in Spain\r\n";

	// Initialize the system
	lpc_pll_init();
  uart0Init(B19200, UART_8N2);
  uart0Puts(pText),

	a=1000;
//  dl = u32 / (a*16);

	// set io pins for led P0.10
	SCS = 0x03;				// select the "fast" version of the I/O ports
	FIO1DIR |= LED;	  // pin P1.21 is an output, everything else is input after reset
	FIO1SET =  LED;	  // led off
	FIO1CLR =  LED;	  // led on


	// endless loop to toggle the red  LED P0.7
	while (1) {
		uart0Putch('*');
		for (j = 0; j < 5000000; j++ );		// wait 500 msec
		FIO1SET = LED;   				// red led off
		for (j = 0; j < 5000000; j++ );		// wait 500 msec
		FIO1CLR = LED;   				// red led on
	}
}



/**********************************************************
                      Initialize
**********************************************************/

//#define PLOCK 0x400

	// 				Setting the Phased Lock Loop (PLL)
	//               ----------------------------------
	//
	// Olimex LPC-P2148 has a 12.0000 mhz crystal
	//
	// We'd like the LPC2148 to run at 60 mhz (has to be an even multiple of crystal)
	//
	// According to the Philips LPC2148 manual:   M = cclk / Fosc	where:	M    = PLL multiplier (bits 0-4 of PLLCFG)
	//																		cclk = 60000000 hz
	//																		Fosc = 12000000 hz
	//
	// Solving:	M = 60000000 / 12000000 = 5
	//
	//			Note: M - 1 must be entered into bits 0-4 of PLLCFG (assign 4 to these bits)
	//
	//
	// The Current Controlled Oscilator (CCO) must operate in the range 156 mhz to 320 mhz
	//
	// According to the Philips LPC2148 manual:	Fcco = cclk * 2 * P    where:	Fcco = CCO frequency
	//																			cclk = 60000000 hz
	//																			P = PLL divisor (bits 5-6 of PLLCFG)
	//
	// Solving:	Fcco = 60000000 * 2 * P
	//			P = 2  (trial value)
	//			Fcco = 60000000 * 2 * 2
	//			Fcc0 = 240000000 hz    (good choice for P since it's within the 156 mhz to 320 mhz range)
	//
	// From Table 22 (page 34) of Philips LPC2148 manual    P = 2, PLLCFG bits 5-6 = 1  (assign 1 to these bits)
	//
	// Finally:      PLLCFG = 0  01  00100  =  0x24
	//
	// Final note: to load PLLCFG register, we must use the 0xAA followed 0x55 write sequence to the PLLFEED register
	//             this is done in the short function feed() below
	//

	// Setting Multiplier and Divider values

void lpc_pll_init(void)
{
  // set PLL multiplier & divisor.
  // values computed from config
  PLLCFG = PLLCFG_MSEL | PLLCFG_PSEL;
  // enable PLL
  PLLCON = PLLCON_PLLE;
  PLLFEED = 0xAA;                       // Make it happen.  These two updates
  PLLFEED = 0x55;                       // MUST occur in sequence.

  // wait for PLL lock
  while (!(PLLSTAT & PLLSTAT_LOCK))
    continue;

  // enable & connect PLL
  PLLCON = PLLCON_PLLE | PLLCON_PLLC;
  PLLFEED = 0xAA;                       // Make it happen.  These two updates
  PLLFEED = 0x55;                       // MUST occur in sequence.

  // setup & enable the MAM
  MAMTIM = MAMTIM_CYCLES;
  MAMCR = MAMCR_FULL;
  // set the peripheral bus speed
  // value computed from config.h
  VPBDIV = VPBDIV_VALUE;                // set the peripheral bus clock speed
}


/*  Stubs for various interrupts (may be replaced later)  */
/*  ----------------------------------------------------  */

void IRQ_Routine (void) {
	while (1) ;
}

void FIQ_Routine (void)  {
	while (1) ;
}


void SWI_Routine (void)  {
	while (1) ;
}


void UNDEF_Routine (void) {
	while (1) ;
}










