/******************************************************************************
 *
 * $RCSfile: uart.c,v $
 * $Revision: 1.1 $
 *
 * This module provides interface routines to the LPC ARM UARTs.
 * Copyright 2004, R O SoftWare
 * No guarantees, warrantees, or promises, implied or otherwise.
 * May be used for hobby or commercial purposes provided copyright
 * notice remains intact.
 *
 *****************************************************************************/
#include <stdlib.h>
#include "lpc214x.h"
#include "lpc_vic.h"
#include "uart.h"

/*
#include <limits.h>
#include "types.h"
#include "uart.h"
#include "uart_isr.h"
#include "lpc_uart.h"
#include "lpc_scb.h"
#include "circular_buf.h"
*/
#define U0_PINSEL        0x00000005    // PINSEL0 Value for UART0
#define U0_PINMASK       0x0000000F    // PINSEL0 Mask for UART0
#define U1_PINSEL        0x00050000    // PINSEL0 Value for UART1
#define U1_PINMASK       0x000F0000    // PINSEL0 Mask for UART1
#define ENABLE_MASK      0x00000C00    // Enablemask for FIO init

/*
#define REB          10
#define DE           11
*/

typedef struct
{
    char devicename[8];
    uint16_t tx_insert_idx;
    uint16_t tx_extract_idx;
    uint16_t tx_buffer_size;
    char *tx_buffer;
    uint16_t rx_insert_idx;
    uint16_t rx_extract_idx;
    uint16_t rx_buffersize;
    char *rx_buffer;
    char buffer[];
} DCB;

#ifdef UART0_SUPPORT
#ifdef UART0_TX_INT_MODE
uint8_t  uart0_tx_buffer[UART0_TX_BUFFER_SIZE];
volatile uint16_t uart0_tx_insert_idx=0, uart0_tx_extract_idx=0;
int      uart0_tx_running;
#endif // UART0_TX_INT_MODE
#ifdef UART0_RX_INT_MODE
uint8_t  uart0_rx_buffer[UART0_RX_BUFFER_SIZE];
volatile uint16_t uart0_rx_insert_idx=0, uart0_rx_extract_idx=0;
#endif // UART0_RX_INT_MODE
#endif // UART0_SUPPORT

#ifdef UART1_SUPPORT
#ifdef UART1_TX_INT_MODE
uint8_t  uart1_tx_buffer[UART1_TX_BUFFER_SIZE];
volatile uint16_t uart1_tx_insert_idx=0, uart1_tx_extract_idx=0;
int      uart1_tx_running;
#endif // UART1_TX_INT_MODE
#ifdef UART0_RX_INT_MODE
uint8_t  uart1_rx_buffer[UART0_RX_BUFFER_SIZE];
volatile uint16_t uart1_rx_insert_idx=0, uart1_rx_extract_idx=0;
#endif // UART0_RX_INT_MODE
#endif // UART1_SUPPORT

/*
#define FIFO_SIZE 512

CIR_BUFFER uart0_rx_buf;
CIR_BUFFER uart1_rx_buf;
U8 uart0_rx_fifo_ptr[FIFO_SIZE];
U8 uart1_rx_fifo_ptr[FIFO_SIZE];
*/

#if 0
void print(char *name, uint32_t value, char *ending)
{
    char s[20];
    uart0Puts(name);
    itoa(value, s, 10);
    uart0Puts(s);
    uart0Puts(ending);
}

void calc_baudrate(uint16_t baudrate)
{
    // static Status uart_set_divisorsNew(LPC_UART_TypeDef *UARTx, uint32_t baudrate);
    // Status errorStatus = ERROR;

    uint32_t uClk;
    uint32_t rate16 = 16 * baudrate;
    uint32_t dval, mval;
    uint32_t dl;

    // get UART block clock
    /*
    if (UARTx == LPC_UART0)
    {
        uClk = CLKPWR_GetPCLK (CLKPWR_PCLKSEL_UART0);
    }
    else if (UARTx == (LPC_UART_TypeDef *)LPC_UART1)
    {
        uClk = CLKPWR_GetPCLK (CLKPWR_PCLKSEL_UART1);
    }
    else if (UARTx == LPC_UART2)
    {
        uClk = CLKPWR_GetPCLK (CLKPWR_PCLKSEL_UART2);
    }
    else if (UARTx == LPC_UART3)
    {
        uClk = CLKPWR_GetPCLK (CLKPWR_PCLKSEL_UART3);
    }
    */

    uClk = 20000000L; //PCLK;
    print("Desired baudrate : ", baudrate, "\r\n");
    print("uCLK . . . . . . : ", uClk/1000000, "MHz\r\n");

    dl = uClk / (baudrate * 16.0);
    print("dl . . . . . . . : ", dl, "\r\n");
    dl = uClk / (16 * dl);
    print("Real baudrate. . : ", dl, "\r\n");

    // The fractional is calculated as
    // (PCLK  % (16 * Baudrate)) / (16 * Baudrate)
    // Let's make it to be the ratio
    // DivVal / MulVal
    //
    //uint32_t rem = uClk % rate16;
    dval = uClk % rate16;

    // The PCLK / (16 * Baudrate) is fractional
    // => dval = pclk % rate16;
    // mval = rate16;
    // now mormalize the ratio
    // dval / mval = 1 / new_mval;
    // new_mval = mval / dval
    // new_dval = 1
    if (dval > 0)
    {
        mval = rate16 / dval;
        dval = 1;

        // in case mval still bigger then 4 bits
        // no adjustment require
        if (mval > 12)
        {
            dval = 0;
        }
    }
    dval &= 0xf;
    mval &= 0xf;

    dl = uClk / (rate16 + rate16 *dval / mval);
/*
    dl  = 31;
    mval= 10;
    dval= 11;
*/
    print("dl . . . . . . . : ", dl, "\r\n");
    print("dval . . . . . . : ", dval, "\r\n");
    print("mval . . . . . . : ", mval, "\r\n");
    uint32_t baud = (uClk * mval) / ((16 * dl) * (mval + dval));
    print("Real baudrate. . : ", baud, "\r\n");


/*
    if (((LPC_UART1_TypeDef *)UARTx) == LPC_UART1)
    {
        ((LPC_UART1_TypeDef *)UARTx)->LCR |= UART_LCR_DLAB_EN;
        ((LPC_UART1_TypeDef *)UARTx)->DLM = (dl >> 8) & 0xff;
        ((LPC_UART1_TypeDef *)UARTx)->DLL = dl & 0xff;
        // Then reset DLAB bit
        ((LPC_UART1_TypeDef *)UARTx)->LCR &= (~UART_LCR_DLAB_EN) & UART_LCR_BITMASK;
        ((LPC_UART1_TypeDef *)UARTx)->FDR = dval | (mval << 4);
    }
    else
    {
        UARTx->LCR |= UART_LCR_DLAB_EN;
        UARTx->DLM = UART_LOAD_DLM(dl);
        UARTx->DLL = UART_LOAD_DLL(dl);
        // Then reset DLAB bit
        UARTx->LCR &= (~UART_LCR_DLAB_EN) & UART_LCR_BITMASK;
        UARTx->FDR = (UART_FDR_MULVAL(mval) \
                   | UART_FDR_DIVADDVAL(dval)) & UART_FDR_BITMASK;
    }
    */
    /*
    printf("New : DL = %d, div = %d, mul = %d\n\r", dl, dval, mval);
    uint32_t rate = uClk / (16 * dl + 16 * dl * dval / mval);
    uint32_t diff = (rate > baudrate ? rate - baudrate : baudrate - rate);
    float err = (float)diff * 100.0 / (float)baudrate;
    printf("New : baudrate = %d, Rate = %d, diff = %d, Err = %.2f\%\n\r", baudrate, rate, diff, err);
    */
}
#endif

#ifdef UART0_SUPPORT
#if defined(UART0_TX_INT_MODE) || defined(UART0_RX_INT_MODE)
/******************************************************************************
 *
 * Function Name: uart0ISR()
 *
 * Description:
 *    This function implements the ISR for UART0.
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    void
 *
 *****************************************************************************/
void __attribute__((interrupt("IRQ"))) uart0ISR(void)
{
    uint8_t iid,ch;
    uint16_t idx;

    // loop until not more interrupt sources
    while (((iid = U0IIR) & UIIR_NO_INT) == 0)
    {
        // identify & process the highest priority interrupt
        switch (iid & UIIR_ID_MASK)
        {
            case UIIR_RLS_INT:                // Receive Line Status
                U0LSR;                          // read LSR to clear
                break;

#ifdef UART0_RX_INT_MODE
            case UIIR_CTI_INT:                // Character Timeout Indicator
            case UIIR_RDA_INT:                // Receive Data Available
                do
                {
                    ch  = U0RBR;
                    idx = (uart0_rx_insert_idx+1) % UART0_RX_BUFFER_SIZE;
                    if (idx!=uart0_rx_extract_idx)
                    {
                        uart0_rx_buffer[uart0_rx_insert_idx]=ch;
                        uart0_rx_insert_idx=idx;
                    }
                } while (U0LSR & ULSR_RDR);
                break;
#endif

#ifdef UART0_TX_INT_MODE
            case UIIR_THRE_INT:               // Transmit Holding Register Empty
                while (U0LSR & ULSR_THRE)
                {
                    // check if more data to send
                    if (uart0_tx_insert_idx != uart0_tx_extract_idx)
                    {
                        U0THR = uart0_tx_buffer[uart0_tx_extract_idx++];
                        uart0_tx_extract_idx %= UART0_TX_BUFFER_SIZE;
                    }
                    else
                    {
                        // no
                        uart0_tx_running = 0;       // clear running flag
                        break;
                    }
                }
                break;
#endif // UART0_TX_INT_MODE

            default:                          // Unknown
                U0LSR;
                U0RBR;
                break;
        }
    }
    VICVectAddr = 0x00000000;             // clear this interrupt from the VIC
}
#endif // defined(UART0_TX_INT_MODE) || defined(UART0_RX_INT_MODE)

/******************************************************************************
 *
 * Function Name: uart0Init()
 *
 * Description:
 *    This function initializes the UART for async mode
 *
 * Calling Sequence:
 *    baudrate divisor - use UART_BAUD macro
 *    mode - see typical modes (uart.h)
 *
 * Returns:
 *    void
 *
 * NOTE: uart0Init(UART_BAUD(9600), UART_8N1);
 *
 *****************************************************************************/
void uart0Init(uint16_t baud, uint8_t mode)
{
    // set port pins for UART0
    PINSEL0 = (PINSEL0 & ~U0_PINMASK) | U0_PINSEL;
    FIO0DIR |= ENABLE_MASK;

    U0IER = 0x00;                         // disable all interrupts
    U0IIR;                                // clear interrupt ID
    U0RBR;                                // clear receive register
    U0LSR;                                // clear line status register

    // set the baudrate
    U0LCR = ULCR_DLAB_ENABLE;             // select divisor latches
    U0DLL = (uint8_t)baud;                // set for baud low byte
    U0DLM = (uint8_t)(baud >> 8);         // set for baud high byte

    // set the number of characters and other
    // user specified operating parameters
    U0LCR = (mode & ~ULCR_DLAB_ENABLE);
    U0FCR = (uint8_t)(UFCR_FIFO_ENABLE + UFCR_FIFO_TRIG1);

#if defined(UART0_TX_INT_MODE) || defined(UART0_RX_INT_MODE)
    // initialize the interrupt vector
    VICIntSelect &= ~ VIC_BIT(VIC_UART0);  // UART0 selected as IRQ
    VICIntEnable |= VIC_BIT(VIC_UART0);    // UART0 interrupt enabled
    VICVectCntl4 = VIC_ENABLE | VIC_UART0;
    VICVectAddr4 = (uint32_t)uart0ISR;    // address of the ISR

#ifdef UART0_TX_INT_MODE
    // initialize the transmit data queue
    uart0_tx_extract_idx = uart0_tx_insert_idx = 0;
    uart0_tx_running = 0;
#endif // UART0_TX_INT_MODE

#ifdef UART0_RX_INT_MODE
    // initialize the receive data queue

    // enable receiver interrupts
    U0IER = UIER_ERBFI;
#endif // UART0_RX_INT_MODE
#endif // (UART0_TX_INT_MODE) || defined(UART0_RX_INT_MODE)
}

/******************************************************************************
 *
 * Function Name: uart0Putch()
 *
 * Description:
 *    This function puts a character into the UART output queue for
 *    transmission.
 *
 * Calling Sequence:
 *    character to be transmitted
 *
 * Returns:
 *    ch on success, -1 on error (queue full)
 *
 *****************************************************************************/
int uart0Putch(int ch)
{
#ifdef UART0_TX_INT_MODE
    uint16_t temp;

    temp = (uart0_tx_insert_idx + 1) % UART0_TX_BUFFER_SIZE;

    while (temp == uart0_tx_extract_idx) ;// return -1; // no room

    U0IER &= ~UIER_ETBEI;                 // disable TX interrupts

    // check if in process of sending data
    if (uart0_tx_running)
    {
        // add to queue
        uart0_tx_buffer[uart0_tx_insert_idx] = (uint8_t)ch;
        uart0_tx_insert_idx = temp;
    }
    else
    {
        // set running flag and write to output register
        uart0_tx_running = 1;
        U0THR = (uint8_t)ch;
    }

    U0IER |= UIER_ETBEI;                  // enable TX interrupts
#else
    while (!(U0LSR & ULSR_THRE))          // wait for TX buffer to empty
        continue;                           // also either WDOG() or swap()

    U0THR = (uint8_t)ch;
#endif // UART0_TX_INT_MODE
    return (uint8_t)ch;
}

/******************************************************************************
 *
 * Function Name: uart0Space()
 *
 * Description:
 *    This function gets the available space in the transmit queue
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    available space in the transmit queue
 *
 *****************************************************************************/
/*
U16 uart0Space(void)
{
#ifdef UART0_TX_INT_MODE
  int space;

  if ((space = (uart0_tx_extract_idx - uart0_tx_insert_idx)) <= 0)
    space += UART0_TX_BUFFER_SIZE;

  return (U16)(space - 1);
#else
  return USHRT_MAX;
#endif
}
*/
/******************************************************************************
 *
 * Function Name: uart0Puts()
 *
 * Description:
 *    This function writes a NULL terminated 'string' to the UART output
 *    queue, returning a pointer to the next character to be written.
 *
 * Calling Sequence:
 *    address of the string
 *
 * Returns:
 *    a pointer to the next character to be written
 *    (\0 if full string is written)
 *
 *****************************************************************************/
const char *uart0Puts(const char *s)
{
  register char ch;

  while ((ch = *s) && (uart0Putch(ch) >= 0)) s++;

  return s;
}

/******************************************************************************
 *
 * Function Name: uart0Write()
 *
 * Description:
 *    This function writes 'count' characters from 'buffer' to the UART
 *    output queue.
 *
 * Calling Sequence:
 *
 *
 * Returns:
 *    0 on success, -1 if insufficient room, -2 on error
 *    NOTE: if insufficient room, no characters are written.
 *
 *****************************************************************************/
/*
int uart0Write(const char *buffer, U16 count)
{
#ifdef UART0_TX_INT_MODE
  if (count > uart0Space())
    return -1;
#endif
  while (count && (uart0Putch(*buffer++) >= 0))
    count--;

  return (count ? -2 : 0);
}
*/
/******************************************************************************
 *
 * Function Name: uart0TxEmpty()
 *
 * Description:
 *    This function returns the status of the UART transmit data
 *    registers.
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    FALSE - either the tx holding or shift register is not empty
 *   !FALSE - if both the tx holding & shift registers are empty
 *
 *****************************************************************************/
/*
int uart0TxEmpty(void)
{
  return (U0LSR & (ULSR_THRE | ULSR_TEMT)) == (ULSR_THRE | ULSR_TEMT);
}
*/
/******************************************************************************
 *
 * Function Name: uart0TxFlush()
 *
 * Description:
 *    This function removes all characters from the UART transmit queue
 *    (without transmitting them).
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    void
 *
 *****************************************************************************/
/*
void uart0TxFlush(void)
{
#ifdef UART0_TX_INT_MODE
//  unsigned cpsr;

  U0FCR |= UFCR_TX_FIFO_RESET;          // clear the TX fifo

  // "Empty" the transmit buffer.
//  cpsr = disableIRQ();                  // disable global interrupts
  U0IER &= ~UIER_ETBEI;                 // disable TX interrupts
//  restoreIRQ(cpsr);                     // restore global interrupts
  uart0_tx_insert_idx = uart0_tx_extract_idx = 0;
#else
  U0FCR |= UFCR_TX_FIFO_RESET;          // clear the TX fifo
#endif
}
*/

/******************************************************************************
 *
 * Function Name: uart0Getch()
 *
 * Description:
 *    This function gets a character from the UART receive queue
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    character on success, -1 if no character is available
 *
 *****************************************************************************/
char uart0Getch(void)
{
#ifdef UART0_RX_INT_MODE
    if (uart0_rx_extract_idx == uart0_rx_insert_idx) return 0;
    char ch=uart0_rx_buffer[uart0_rx_extract_idx];
    uart0_rx_extract_idx=(uart0_rx_extract_idx+1) % UART0_RX_BUFFER_SIZE;
    return ch;
#else
    if (U0LSR & ULSR_RDR)  // check if character is available
        return U0RBR;      // return character
    return 0;
#endif // UART0_RX_INT_MODE
return 0;
}

#endif // UART0_SUPPORT

#ifdef UART1_SUPPORT
/******************************************************************************
 *
 * Function Name: uart1Init()
 *
 * Description:
 *    This function initializes the UART for async mode
 *
 * Calling Sequence:
 *    baudrate divisor - use UART_BAUD macro
 *    mode - see typical modes (uart.h)
 *    fmode - see typical fmodes (uart.h)
 *
 * Returns:
 *    void
 *
 * NOTE: uart1Init(UART_BAUD(9600), UART_8N1, UART_FIFO_8);
 *
 *****************************************************************************/
/*
void uart1Init(U16 baud, U8 mode, U8 fmode)
{
  // set port pins for UART1
  PINSEL0 = (PINSEL0 & ~U1_PINMASK) | U1_PINSEL;
  FIO0DIR |= ENABLE_MASK;
//  FIO0SET |=(1<<DE);
//  FIO0CLR |=(1<<REB);

  U1IER = 0x00;                         // disable all interrupts
  U1IIR;                                // clear interrupt ID
  U1RBR;                                // clear receive register
  U1LSR;                                // clear line status register

  // set the baudrate
  U1LCR = ULCR_DLAB_ENABLE;             // select divisor latches
  U1DLL = (U8)baud;                // set for baud low byte
  U1DLM = (U8)(baud >> 8);         // set for baud high byte

  // set the number of characters and other
  // user specified operating parameters
  U1LCR = (mode & ~ULCR_DLAB_ENABLE);
  U1FCR = fmode;

#if defined(UART1_TX_INT_MODE) || defined(UART1_RX_INT_MODE)
  // initialize the interrupt vector
  VICIntSelect &= ~VIC_BIT(VIC_UART1);  // UART1 selected as IRQ
  VICIntEnable |= VIC_BIT(VIC_UART1);    // UART1 interrupt enabled
  VICVectCntl3 = VIC_ENABLE | VIC_UART1;
  VICVectAddr3 = (U32)uart1ISR;    // address of the ISR

#ifdef UART1_TX_INT_MODE
  uart1_tx_extract_idx = uart1_tx_insert_idx = 0;
  uart1_tx_running = 0;
#endif

#ifdef UART1_RX_INT_MODE
  // initialize data queues

  // enable receiver interrupts
  U1IER |= UIER_ERBFI;
#endif
#endif
}
*/
/******************************************************************************
 *
 * Function Name: uart1Putch()
 *
 * Description:
 *    This function puts a character into the UART output queue for
 *    transmission.
 *
 * Calling Sequence:
 *    ch - character to be transmitted
 *
 * Returns:
 *    ch on success, -1 on error (queue full)
 *
 *****************************************************************************/
/*
int uart1Putch(int ch)
{

#ifdef UART1_TX_INT_MODE
  U16 temp;

  temp = (uart1_tx_insert_idx + 1) % UART1_TX_BUFFER_SIZE;

  if (temp == uart1_tx_extract_idx)
    return -1;                          // no room

  U1IER &= ~UIER_ETBEI;                 // disable TX interrupts

  // check if in process of sending data
  if (uart1_tx_running)
    {
    // add to queue
    uart1_tx_buffer[uart1_tx_insert_idx] = (U8)ch;
    uart1_tx_insert_idx = temp;
    }
  else
    {
    // set running flag and write to output register
    uart1_tx_running = 1;
    U1THR = (U8)ch;
    }

  U1IER |= UIER_ETBEI;                  // enable TX interrupts
#else
  while (!(U1LSR & ULSR_THRE))          // wait for TX buffer to empty
    continue;                           // also either WDOG() or swap()

  U1THR = (U8)ch;
#endif
  return (U8)ch;
}
*/
/******************************************************************************
 *
 * Function Name: uart1Space()
 *
 * Description:
 *    This function gets the available space in the transmit queue
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    available space in the transmit queue
 *
 *****************************************************************************/
/*
U16 uart1Space(void)
{
#ifdef UART1_TX_INT_MODE
  int space;

  if ((space = (uart1_tx_extract_idx - uart1_tx_insert_idx)) <= 0)
    space += UART1_TX_BUFFER_SIZE;

  return (U16)(space - 1);
#else
  return USHRT_MAX;
#endif
}
*/
/******************************************************************************
 *
 * Function Name: uart1Puts()
 *
 * Description:
 *    This function writes a NULL terminated 'string' to the UART output
 *    queue, returning a pointer to the next character to be written.
 *
 * Calling Sequence:
 *    address of the string
 *
 * Returns:
 *    a pointer to the next character to be written
 *    (\0 if full string is written)
 *
 *****************************************************************************/
/*
const char *uart1Puts(const char *string)
{
  register char ch;

  while ((ch = *string) && (uart1Putch(ch) >= 0))
    string++;

  return string;
}
*/
/******************************************************************************
 *
 * Function Name: uart1Write()
 *
 * Description:
 *    This function writes 'count' characters from 'buffer' to the UART
 *    output queue.
 *
 * Calling Sequence:
 *
 *
 * Returns:
 *    0 on success, -1 if insufficient room, -2 on error
 *    NOTE: if insufficient room, no characters are written.
 *
 *****************************************************************************/
/*
int uart1Write(const char *buffer, U16 count)
{
#ifdef UART1_TX_INT_MODE
  if (count > uart1Space())
    return -1;
#endif
  while (count && (uart1Putch(*buffer++) >= 0))
    count--;

  return (count ? -2 : 0);
}
*/
/******************************************************************************
 *
 * Function Name: uart1TxEmpty()
 *
 * Description:
 *    This function returns the status of the UART transmit data
 *    registers.
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    FALSE - either the tx holding or shift register is not empty
 *   !FALSE - if both the tx holding & shift registers are empty
 *
 *****************************************************************************/
/*
int uart1TxEmpty(void)
{
  return (U1LSR & (ULSR_THRE | ULSR_TEMT)) == (ULSR_THRE | ULSR_TEMT);
}
*/
/******************************************************************************
 *
 * Function Name: uart1TxFlush()
 *
 * Description:
 *    This function removes all characters from the UART transmit queue
 *    (without transmitting them).
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    void
 *
 *****************************************************************************/
/*
void uart1TxFlush(void)
{
#ifdef UART1_TX_INT_MODE
//  unsigned cpsr;

  U1FCR |= UFCR_TX_FIFO_RESET;          // clear the TX fifo

  // "Empty" the transmit buffer.
//  cpsr = disableIRQ();                  // disable global interrupts
  U1IER &= ~UIER_ETBEI;                 // disable TX interrupts
//  restoreIRQ(cpsr);                     // restore global interrupts
  uart1_tx_insert_idx = uart1_tx_extract_idx = 0;
#else
  U1FCR |= UFCR_TX_FIFO_RESET;          // clear the TX fifo
#endif
}
*/
/******************************************************************************
 *
 * Function Name: uart1Getch()
 *
 * Description:
 *    This function gets a character from the UART receive queue
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    character on success, -1 if no character is available
 *
 *****************************************************************************/
/*
S8 uart1Getch(U8 *ch)
{

#ifdef UART1_RX_INT_MODE
#if 0
if(!popFromCirBuf(&uart1_rx_buf,ch,1))
return -1;
else
return 0;
#endif
#else
  if (U1LSR & ULSR_RDR)                 // check if character is available
    return U1RBR;                       // return character

  return -1;
#endif
return 0;
}

#endif
*/
/**
*******************************************************************************
  Function Name : uart0Receive()

  Description :

  Input :

  Output :	none

  Note :
*******************************************************************************
*/
/*
S8 uart0Receive(U8 *buf, U16 size)
{
  S32 retval=0;

  retval = popFromCirBuf(&uart0_rx_buf, buf, size);

  if(retval!=size)
    return -1;
  else
    return 0;
}
*/
/**
*******************************************************************************
  Function Name : uart1Receive()

  Description :

  Input :

  Output :	none

  Note :
*******************************************************************************
*/
/*
S8 uart1Receive(U8 *buf, U16 size)
{
  S32 retval=0;

  retval = popFromCirBuf(&uart1_rx_buf, buf, size);

  if(retval!=size)
    return -1;
  else
    return 0;
}
*/
/**
*******************************************************************************
  Function Name : init_uart0()

  Description :

  Input :

  Output :	none

  Note :
*******************************************************************************
*/
/*
void init_uart0(void)
{
  uart0Init(UART_BAUD(HOST_BAUD), UART_8N1, UART_FIFO_8);
  CirBufInit(&uart0_rx_buf, FIFO_SIZE, uart0_rx_fifo_ptr);
}
*/
/**
*******************************************************************************
  Function Name : init_uart1()

  Description :

  Input :

  Output :	none

  Note :
*******************************************************************************
*/
/*
void init_uart1(void)
{
	uart1Init(UART_BAUD(HOST_BAUD), UART_8N1, UART_FIFO_8);
  CirBufInit(&uart1_rx_buf, FIFO_SIZE, uart1_rx_fifo_ptr);
}
*/
#endif // UART1_SUPPORT
